CheapString

Struct CheapString 

pub struct CheapString { /* private fields */ }
Stores an Rc which allows for the standard stack strings to be stored on heap, it also allows shallow cloning which just bumps the ref counter up, which is where the name cheap string comes from.

Example

use cheap_string::CheapString;
 
let str = CheapString::from("Hello, world!");
println!("{}", str);

Implementations

Source

impl CheapString

pub fn from(str: &str) -> Self

pub fn chars(&self) -> Chars<'_>

pub fn len(&self) -> usize

pub fn as_str(&self) -> &str